@@ -1,10 +1,10 @@
-/* Source Installer, Copyright (c) 2005 Claudio Fontana
+/* Source Installer, Copyright (c) 2005,2006,2007 Claudio Fontana
 
  srcexport.c - export functions
 
  This program is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2 of the License, or
+ the Free Software Foundation; either version 3 of the License, or
      (at your option) any later version.
 
  This program is distributed in the hope that it will be useful,
@@ -438,7 +438,7 @@ static int _export_binary_package_aux(struct _package_info* info, char* filename
 
     /* now move binary package to target */
 
-    rv = srcinst_spawn_wait(PRG_mv, tmp, filename); free(tmp);
+    rv = srcinst_spawn_wait(PRG_mv, tmp, filename, 0); free(tmp);
     if (!rv)
       return 0;
   }
